@@ -17,8 +17,8 @@
 
 # GOOGLE_MAPS_API_KEY = 'ABQIAAAApZ2euq0Rw9q9gnvrFpM9exTnaMynjZlWua31ZRN9Bu7KwLftLRQ43gnDTGdinhoU7RuKLZRQxMKcVg'
 GOOGLE_MAPS_API_KEY = ''
-VERSION_STRING = 'barriosquare 0.3.1'
-SHORT_VERSION_STRING = '0.3.1'
+VERSION_STRING = 'barriosquare 0.3.2'
+SHORT_VERSION_STRING = '0.3.2'
 # key and secret granted by the service provider for this consumer application - same as the MockOAuthDataStore
 CONSUMER_KEY = '73da08e67b46cb1dc10fd43ea813071104af9fe79'
 CONSUMER_SECRET = 'c9fadf4a225e74d907053aecd12f23d5'
@@ -27,7 +27,7 @@ TWITTER_CONSUMER_SECRET = 'iOdH21SjnN5CQWDXbsiFgiIjqqMrvva03OnpvmmS0'
 SERVER = 'foursquare.com'
 PORT = 80
 API_PREFIX_URL = 'http://api.foursquare.com/v1/'
-AUTHORIZATION_EXCHANGE_URL = 'http://api.playfoursquare.com/v1/authexchange'
+AUTHORIZATION_EXCHANGE_URL = 'http://api.foursquare.com/v1/authexchange'
 REQUEST_TOKEN_URL = 'http://foursquare.com/oauth/request_token'
 ACCESS_TOKEN_URL = 'http://foursquare.com/oauth/access_token'
 AUTHORIZATION_URL = 'http://foursquare.com/oauth/authorize'
